Struct procspawn::PoolBuilder [−][src]
pub struct PoolBuilder { /* fields omitted */ }Expand description
Utility to configure a pool.
This requires the pool feature.
Implementations
Set an environment variable in the spawned process.
Equivalent to Command::env
Set environment variables in the spawned process.
Equivalent to Command::envs
Removes an environment variable in the spawned process.
Equivalent to Command::env_remove
Clears all environment variables in the spawned process.
Equivalent to Command::env_clear
Sets the child process’s user ID. This translates to a
setuid call in the child process. Failure in the setuid
call will cause the spawn to fail.
Unix-specific extension only available on unix.
Equivalent to std::os::unix::process::CommandExt::uid
Similar to uid, but sets the group ID of the child process. This has
the same semantics as the uid field.
Unix-specific extension only available on unix.
Equivalent to std::os::unix::process::CommandExt::gid
Schedules a closure to be run just before the exec function is
invoked.
Safety
This method is inherently unsafe. See the notes of the unix command ext for more information.
Equivalent to std::os::unix::process::CommandExt::pre_exec
Redirects stdin to /dev/null.
Redirects stdout to /dev/null.
Redirects stderr to /dev/null.
Creates the pool.